@@ -5,7 +5,7 @@
 #'
 #'@description  Creates a plot of the Acc Data given a resolution.
 #'
-#'@param x should be an Acc Data object.
+#'@param x should be an AccData object.
 #'@param what What variable to plot against time. Options are: \enumerate{
 #'\item sd: Standard of movement given the resolutions
 #'\item mean: Mean of movementgiven the resolutions
@@ -34,26 +34,32 @@
 #' plotAccData(x, what = ("voltage"))
 #' }
 
-plotAccData <- function(x, what = c("sd", "mean", "temperature", "light", "voltage"), draw = TRUE, resolution = 200,...){
+plotAccData <- function(x, 
+                        what = c("sd", "mean", "temperature", "light", "voltage"), 
+                        draw = TRUE, 
+                        resolution = 200,
+                        ...){
+  
   what = match.arg(what)
   epoch = floor((nrow(x$data.out)/resolution + 1)/x$freq)
   
   if (class(x) == "AccData"){
-    
     # Create the time sequence to plot over. 
     t1 = as.POSIXct(x$data.out[1, 1], tz = "GMT", origin = "1970-01-01")
     t2 = as.POSIXct(x$data.out[length(x$data.out[,1]), 1], tz = "GMT", origin = "1970-01-01")
-    t_del = (t2-t1)/5
-    time_seq = seq(t1,t2,by = t_del)
+    t_del = (t2 - t1)/5
+    time_seq = seq(t1, t2, by = t_del)
     
     if (what == "sd"){
       obj = apply.epoch(x$data.out, epoch.size = epoch, incl.date = TRUE, FUN = function(t) sd(svm(t)))
     } else if (what == "mean"){
       obj = apply.epoch(x$data.out, epoch.size = epoch, incl.date = TRUE, FUN = function(t) mean(svm(t)))
     } else if (what == "temperature"){
-      obj = apply.epoch(x$data.out, epoch.size = epoch, incl.date = TRUE, function(t) mean(t[,7]))
+      data = cbind(x$data.out[,1], x$data.out[,7])
+      obj = apply.epoch(x$data.out, epoch.size = epoch, incl.date = TRUE, function(t) mean(t[,2]))
     } else  if (what == "light"){
-      obj = apply.epoch(x$data.out, epoch.size = epoch, incl.date = TRUE, FUN = function(t) max(t[,5]))
+      data = cbind(x$data.out[,1], x$data.out[,5])
+      obj = apply.epoch(data, epoch.size = epoch, incl.date = TRUE, FUN = function(t) max(t[,2]))
     } else if (what == "voltage"){
       obj = data.frame("time" = x$page.timestamps, "Voltage" = x$page.volts)
      
